package files

import (
	"errors"
	"io"
	"net/http"
)

type Downloader interface {
	Download(dst io.Writer, file *File) error
}

type downloader struct{}

func NewDownloader() Downloader {
	return &downloader{}
}

func (d *downloader) Download(dst io.Writer, file *File) error {
	r, err := http.Get(file.URL)
	if err != nil {
		return err
	}
	defer r.Body.Close()

	if r.StatusCode != http.StatusOK {
		return errors.New("download request failed: " + r.Status)
	}

	_, err = io.Copy(dst, r.Body)
	return err
}
